@@ -4,7 +4,7 @@ from dynamic_validation import models
 
 
 class ViolationAdmin(admin.ModelAdmin):
-    list_display = ('rule', 'key', 'validation_object', 'message', 'violated_fields')
+    list_display = ('rule', 'key', 'trigger_model', 'message', 'violated_fields')
     list_filter = ('rule', )
 
 admin.site.register(models.Violation, ViolationAdmin)
\ No newline at end of file
