@@ -11,22 +11,22 @@ __all__ = ('violations_for', )
 def violations_for(parser, token):
     """
     usage:
-    {% violations_for validation_object as var_name %}
+    {% violations_for trigger_model as var_name %}
     """
     bits = token.split_contents()
     if len(bits) != 4 or bits[2] != 'as':
-        raise TemplateSyntaxError("Must pass 'validation_object as var_name' to %s tag" % bits[0])
+        raise TemplateSyntaxError("Must pass 'trigger_model as var_name' to %s tag" % bits[0])
     return ViolationsForNode(bits[1], bits[3])
 
 class ViolationsForNode(Node):
-    def __init__(self, obj, var_name):
-        self.obj = Variable(obj)
+    def __init__(self, trigger_model, var_name):
+        self.trigger_model = Variable(trigger_model)
         self.var_name = var_name
 
     def render(self, context):
         try:
-            obj = self.obj.resolve(context)
-            violations = models.Violation.objects.get_by_validation_object(obj)
+            trigger_model = self.trigger_model.resolve(context)
+            violations = models.Violation.objects.get_by_trigger_model(trigger_model)
             context[self.var_name] = models.ViolationsWrapper(violations)
         except VariableDoesNotExist: pass
         return ''
\ No newline at end of file
